import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AcmpcaCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#certificate_authority_arn AcmpcaCertificate#certificate_authority_arn}.
     *
     * @stability stable
     */
    readonly certificateAuthorityArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#certificate_signing_request AcmpcaCertificate#certificate_signing_request}.
     *
     * @stability stable
     */
    readonly certificateSigningRequest: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#signing_algorithm AcmpcaCertificate#signing_algorithm}.
     *
     * @stability stable
     */
    readonly signingAlgorithm: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#template_arn AcmpcaCertificate#template_arn}.
     *
     * @stability stable
     */
    readonly templateArn?: string;
    /**
     * validity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#validity AcmpcaCertificate#validity}
     *
     * @stability stable
     */
    readonly validity: AcmpcaCertificateValidity[];
}
/**
 * @stability stable
 */
export interface AcmpcaCertificateValidity {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#type AcmpcaCertificate#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#value AcmpcaCertificate#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html aws_acmpca_certificate}.
 *
 * @stability stable
 */
export declare class AcmpcaCertificate extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html aws_acmpca_certificate} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AcmpcaCertificateConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get certificate(): string;
    private _certificateAuthorityArn;
    /**
     * @stability stable
     */
    get certificateAuthorityArn(): string;
    /**
     * @stability stable
     */
    set certificateAuthorityArn(value: string);
    /**
     * @stability stable
     */
    get certificateAuthorityArnInput(): string;
    /**
     * @stability stable
     */
    get certificateChain(): string;
    private _certificateSigningRequest;
    /**
     * @stability stable
     */
    get certificateSigningRequest(): string;
    /**
     * @stability stable
     */
    set certificateSigningRequest(value: string);
    /**
     * @stability stable
     */
    get certificateSigningRequestInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _signingAlgorithm;
    /**
     * @stability stable
     */
    get signingAlgorithm(): string;
    /**
     * @stability stable
     */
    set signingAlgorithm(value: string);
    /**
     * @stability stable
     */
    get signingAlgorithmInput(): string;
    private _templateArn?;
    /**
     * @stability stable
     */
    get templateArn(): string;
    /**
     * @stability stable
     */
    set templateArn(value: string);
    /**
     * @stability stable
     */
    resetTemplateArn(): void;
    /**
     * @stability stable
     */
    get templateArnInput(): string | undefined;
    private _validity;
    /**
     * @stability stable
     */
    get validity(): AcmpcaCertificateValidity[];
    /**
     * @stability stable
     */
    set validity(value: AcmpcaCertificateValidity[]);
    /**
     * @stability stable
     */
    get validityInput(): AcmpcaCertificateValidity[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
