import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ApiGatewayMethodSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#method_path ApiGatewayMethodSettings#method_path}.
     *
     * @stability stable
     */
    readonly methodPath: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#rest_api_id ApiGatewayMethodSettings#rest_api_id}.
     *
     * @stability stable
     */
    readonly restApiId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#stage_name ApiGatewayMethodSettings#stage_name}.
     *
     * @stability stable
     */
    readonly stageName: string;
    /**
     * settings block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#settings ApiGatewayMethodSettings#settings}
     *
     * @stability stable
     */
    readonly settings: ApiGatewayMethodSettingsSettings[];
}
/**
 * @stability stable
 */
export interface ApiGatewayMethodSettingsSettings {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#cache_data_encrypted ApiGatewayMethodSettings#cache_data_encrypted}.
     *
     * @stability stable
     */
    readonly cacheDataEncrypted?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#cache_ttl_in_seconds ApiGatewayMethodSettings#cache_ttl_in_seconds}.
     *
     * @stability stable
     */
    readonly cacheTtlInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#caching_enabled ApiGatewayMethodSettings#caching_enabled}.
     *
     * @stability stable
     */
    readonly cachingEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#data_trace_enabled ApiGatewayMethodSettings#data_trace_enabled}.
     *
     * @stability stable
     */
    readonly dataTraceEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#logging_level ApiGatewayMethodSettings#logging_level}.
     *
     * @stability stable
     */
    readonly loggingLevel?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#metrics_enabled ApiGatewayMethodSettings#metrics_enabled}.
     *
     * @stability stable
     */
    readonly metricsEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#require_authorization_for_cache_control ApiGatewayMethodSettings#require_authorization_for_cache_control}.
     *
     * @stability stable
     */
    readonly requireAuthorizationForCacheControl?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#throttling_burst_limit ApiGatewayMethodSettings#throttling_burst_limit}.
     *
     * @stability stable
     */
    readonly throttlingBurstLimit?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#throttling_rate_limit ApiGatewayMethodSettings#throttling_rate_limit}.
     *
     * @stability stable
     */
    readonly throttlingRateLimit?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#unauthorized_cache_control_header_strategy ApiGatewayMethodSettings#unauthorized_cache_control_header_strategy}.
     *
     * @stability stable
     */
    readonly unauthorizedCacheControlHeaderStrategy?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html aws_api_gateway_method_settings}.
 *
 * @stability stable
 */
export declare class ApiGatewayMethodSettings extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html aws_api_gateway_method_settings} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiGatewayMethodSettingsConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _methodPath;
    /**
     * @stability stable
     */
    get methodPath(): string;
    /**
     * @stability stable
     */
    set methodPath(value: string);
    /**
     * @stability stable
     */
    get methodPathInput(): string;
    private _restApiId;
    /**
     * @stability stable
     */
    get restApiId(): string;
    /**
     * @stability stable
     */
    set restApiId(value: string);
    /**
     * @stability stable
     */
    get restApiIdInput(): string;
    private _stageName;
    /**
     * @stability stable
     */
    get stageName(): string;
    /**
     * @stability stable
     */
    set stageName(value: string);
    /**
     * @stability stable
     */
    get stageNameInput(): string;
    private _settings;
    /**
     * @stability stable
     */
    get settings(): ApiGatewayMethodSettingsSettings[];
    /**
     * @stability stable
     */
    set settings(value: ApiGatewayMethodSettingsSettings[]);
    /**
     * @stability stable
     */
    get settingsInput(): ApiGatewayMethodSettingsSettings[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
