import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AwsProviderConfig {
    /**
     * The access key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#access_key AwsProvider#access_key}
     *
     * @stability stable
     */
    readonly accessKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#allowed_account_ids AwsProvider#allowed_account_ids}.
     *
     * @stability stable
     */
    readonly allowedAccountIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#forbidden_account_ids AwsProvider#forbidden_account_ids}.
     *
     * @stability stable
     */
    readonly forbiddenAccountIds?: string[];
    /**
     * The address of an HTTP proxy to use when accessing the AWS API.
     *
     * Can also be configured using the `HTTP_PROXY` or `HTTPS_PROXY` environment variables.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#http_proxy AwsProvider#http_proxy}
     *
     * @stability stable
     */
    readonly httpProxy?: string;
    /**
     * Explicitly allow the provider to perform "insecure" SSL requests. If omitted, default value is `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#insecure AwsProvider#insecure}
     *
     * @stability stable
     */
    readonly insecure?: boolean | cdktf.IResolvable;
    /**
     * The maximum number of times an AWS API request is being executed.
     *
     * If the API request still fails, an error is
     * thrown.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#max_retries AwsProvider#max_retries}
     *
     * @stability stable
     */
    readonly maxRetries?: number;
    /**
     * The profile for API operations. If not set, the default profile created with `aws configure` will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#profile AwsProvider#profile}
     *
     * @stability stable
     */
    readonly profile?: string;
    /**
     * The region where AWS operations will take place. Examples are us-east-1, us-west-2, etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#region AwsProvider#region}
     *
     * @stability stable
     */
    readonly region: string;
    /**
     * Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY). Specific to the Amazon S3 service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#s3_force_path_style AwsProvider#s3_force_path_style}
     *
     * @stability stable
     */
    readonly s3ForcePathStyle?: boolean | cdktf.IResolvable;
    /**
     * The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#secret_key AwsProvider#secret_key}
     *
     * @stability stable
     */
    readonly secretKey?: string;
    /**
     * The path to the shared credentials file. If not set this defaults to ~/.aws/credentials.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#shared_credentials_file AwsProvider#shared_credentials_file}
     *
     * @stability stable
     */
    readonly sharedCredentialsFile?: string;
    /**
     * Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS available/implemented.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#skip_credentials_validation AwsProvider#skip_credentials_validation}
     *
     * @stability stable
     */
    readonly skipCredentialsValidation?: boolean | cdktf.IResolvable;
    /**
     * Skip getting the supported EC2 platforms. Used by users that don't have ec2:DescribeAccountAttributes permissions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#skip_get_ec2_platforms AwsProvider#skip_get_ec2_platforms}
     *
     * @stability stable
     */
    readonly skipGetEc2Platforms?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#skip_metadata_api_check AwsProvider#skip_metadata_api_check}.
     *
     * @stability stable
     */
    readonly skipMetadataApiCheck?: boolean | cdktf.IResolvable;
    /**
     * Skip static validation of region name.
     *
     * Used by users of alternative AWS-like APIs or users w/ access to regions that are not public (yet).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#skip_region_validation AwsProvider#skip_region_validation}
     *
     * @stability stable
     */
    readonly skipRegionValidation?: boolean | cdktf.IResolvable;
    /**
     * Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#skip_requesting_account_id AwsProvider#skip_requesting_account_id}
     *
     * @stability stable
     */
    readonly skipRequestingAccountId?: boolean | cdktf.IResolvable;
    /**
     * session token. A session token is only required if you are using temporary security credentials.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#token AwsProvider#token}
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * Alias name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#alias AwsProvider#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * assume_role block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#assume_role AwsProvider#assume_role}
     *
     * @stability stable
     */
    readonly assumeRole?: AwsProviderAssumeRole[];
    /**
     * default_tags block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#default_tags AwsProvider#default_tags}
     *
     * @stability stable
     */
    readonly defaultTags?: AwsProviderDefaultTags[];
    /**
     * endpoints block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#endpoints AwsProvider#endpoints}
     *
     * @stability stable
     */
    readonly endpoints?: AwsProviderEndpoints[];
    /**
     * ignore_tags block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ignore_tags AwsProvider#ignore_tags}
     *
     * @stability stable
     */
    readonly ignoreTags?: AwsProviderIgnoreTags[];
}
/**
 * @stability stable
 */
export interface AwsProviderAssumeRole {
    /**
     * Seconds to restrict the assume role session duration.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#duration_seconds AwsProvider#duration_seconds}
     *
     * @stability stable
     */
    readonly durationSeconds?: number;
    /**
     * Unique identifier that might be required for assuming a role in another account.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#external_id AwsProvider#external_id}
     *
     * @stability stable
     */
    readonly externalId?: string;
    /**
     * IAM Policy JSON describing further restricting permissions for the IAM Role being assumed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#policy AwsProvider#policy}
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Amazon Resource Names (ARNs) of IAM Policies describing further restricting permissions for the IAM Role being assumed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#policy_arns AwsProvider#policy_arns}
     *
     * @stability stable
     */
    readonly policyArns?: string[];
    /**
     * Amazon Resource Name of an IAM Role to assume prior to making API calls.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#role_arn AwsProvider#role_arn}
     *
     * @stability stable
     */
    readonly roleArn?: string;
    /**
     * Identifier for the assumed role session.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#session_name AwsProvider#session_name}
     *
     * @stability stable
     */
    readonly sessionName?: string;
    /**
     * Assume role session tags.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#tags AwsProvider#tags}
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Assume role session tag keys to pass to any subsequent sessions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#transitive_tag_keys AwsProvider#transitive_tag_keys}
     *
     * @stability stable
     */
    readonly transitiveTagKeys?: string[];
}
/**
 * @stability stable
 */
export interface AwsProviderDefaultTags {
    /**
     * Resource tags to default across all resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#tags AwsProvider#tags}
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface AwsProviderEndpoints {
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#accessanalyzer AwsProvider#accessanalyzer}
     *
     * @stability stable
     */
    readonly accessanalyzer?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#acm AwsProvider#acm}
     *
     * @stability stable
     */
    readonly acm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#acmpca AwsProvider#acmpca}
     *
     * @stability stable
     */
    readonly acmpca?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#amplify AwsProvider#amplify}
     *
     * @stability stable
     */
    readonly amplify?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#apigateway AwsProvider#apigateway}
     *
     * @stability stable
     */
    readonly apigateway?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#appconfig AwsProvider#appconfig}
     *
     * @stability stable
     */
    readonly appconfig?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#applicationautoscaling AwsProvider#applicationautoscaling}
     *
     * @stability stable
     */
    readonly applicationautoscaling?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#applicationinsights AwsProvider#applicationinsights}
     *
     * @stability stable
     */
    readonly applicationinsights?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#appmesh AwsProvider#appmesh}
     *
     * @stability stable
     */
    readonly appmesh?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#apprunner AwsProvider#apprunner}
     *
     * @stability stable
     */
    readonly apprunner?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#appstream AwsProvider#appstream}
     *
     * @stability stable
     */
    readonly appstream?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#appsync AwsProvider#appsync}
     *
     * @stability stable
     */
    readonly appsync?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#athena AwsProvider#athena}
     *
     * @stability stable
     */
    readonly athena?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#auditmanager AwsProvider#auditmanager}
     *
     * @stability stable
     */
    readonly auditmanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#autoscaling AwsProvider#autoscaling}
     *
     * @stability stable
     */
    readonly autoscaling?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#autoscalingplans AwsProvider#autoscalingplans}
     *
     * @stability stable
     */
    readonly autoscalingplans?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#backup AwsProvider#backup}
     *
     * @stability stable
     */
    readonly backup?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#batch AwsProvider#batch}
     *
     * @stability stable
     */
    readonly batch?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#budgets AwsProvider#budgets}
     *
     * @stability stable
     */
    readonly budgets?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#chime AwsProvider#chime}
     *
     * @stability stable
     */
    readonly chime?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloud9 AwsProvider#cloud9}
     *
     * @stability stable
     */
    readonly cloud9?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudcontrolapi AwsProvider#cloudcontrolapi}
     *
     * @stability stable
     */
    readonly cloudcontrolapi?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudformation AwsProvider#cloudformation}
     *
     * @stability stable
     */
    readonly cloudformation?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudfront AwsProvider#cloudfront}
     *
     * @stability stable
     */
    readonly cloudfront?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudhsm AwsProvider#cloudhsm}
     *
     * @stability stable
     */
    readonly cloudhsm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudsearch AwsProvider#cloudsearch}
     *
     * @stability stable
     */
    readonly cloudsearch?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudtrail AwsProvider#cloudtrail}
     *
     * @stability stable
     */
    readonly cloudtrail?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudwatch AwsProvider#cloudwatch}
     *
     * @stability stable
     */
    readonly cloudwatch?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudwatchevents AwsProvider#cloudwatchevents}
     *
     * @stability stable
     */
    readonly cloudwatchevents?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cloudwatchlogs AwsProvider#cloudwatchlogs}
     *
     * @stability stable
     */
    readonly cloudwatchlogs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#codeartifact AwsProvider#codeartifact}
     *
     * @stability stable
     */
    readonly codeartifact?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#codebuild AwsProvider#codebuild}
     *
     * @stability stable
     */
    readonly codebuild?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#codecommit AwsProvider#codecommit}
     *
     * @stability stable
     */
    readonly codecommit?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#codedeploy AwsProvider#codedeploy}
     *
     * @stability stable
     */
    readonly codedeploy?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#codepipeline AwsProvider#codepipeline}
     *
     * @stability stable
     */
    readonly codepipeline?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#codestarconnections AwsProvider#codestarconnections}
     *
     * @stability stable
     */
    readonly codestarconnections?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cognitoidentity AwsProvider#cognitoidentity}
     *
     * @stability stable
     */
    readonly cognitoidentity?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cognitoidp AwsProvider#cognitoidp}
     *
     * @stability stable
     */
    readonly cognitoidp?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#configservice AwsProvider#configservice}
     *
     * @stability stable
     */
    readonly configservice?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#connect AwsProvider#connect}
     *
     * @stability stable
     */
    readonly connect?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#cur AwsProvider#cur}
     *
     * @stability stable
     */
    readonly cur?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#dataexchange AwsProvider#dataexchange}
     *
     * @stability stable
     */
    readonly dataexchange?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#datapipeline AwsProvider#datapipeline}
     *
     * @stability stable
     */
    readonly datapipeline?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#datasync AwsProvider#datasync}
     *
     * @stability stable
     */
    readonly datasync?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#dax AwsProvider#dax}
     *
     * @stability stable
     */
    readonly dax?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#detective AwsProvider#detective}
     *
     * @stability stable
     */
    readonly detective?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#devicefarm AwsProvider#devicefarm}
     *
     * @stability stable
     */
    readonly devicefarm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#directconnect AwsProvider#directconnect}
     *
     * @stability stable
     */
    readonly directconnect?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#dlm AwsProvider#dlm}
     *
     * @stability stable
     */
    readonly dlm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#dms AwsProvider#dms}
     *
     * @stability stable
     */
    readonly dms?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#docdb AwsProvider#docdb}
     *
     * @stability stable
     */
    readonly docdb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ds AwsProvider#ds}
     *
     * @stability stable
     */
    readonly ds?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#dynamodb AwsProvider#dynamodb}
     *
     * @stability stable
     */
    readonly dynamodb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ec2 AwsProvider#ec2}
     *
     * @stability stable
     */
    readonly ec2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ecr AwsProvider#ecr}
     *
     * @stability stable
     */
    readonly ecr?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ecrpublic AwsProvider#ecrpublic}
     *
     * @stability stable
     */
    readonly ecrpublic?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ecs AwsProvider#ecs}
     *
     * @stability stable
     */
    readonly ecs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#efs AwsProvider#efs}
     *
     * @stability stable
     */
    readonly efs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#eks AwsProvider#eks}
     *
     * @stability stable
     */
    readonly eks?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#elasticache AwsProvider#elasticache}
     *
     * @stability stable
     */
    readonly elasticache?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#elasticbeanstalk AwsProvider#elasticbeanstalk}
     *
     * @stability stable
     */
    readonly elasticbeanstalk?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#elastictranscoder AwsProvider#elastictranscoder}
     *
     * @stability stable
     */
    readonly elastictranscoder?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#elb AwsProvider#elb}
     *
     * @stability stable
     */
    readonly elb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#emr AwsProvider#emr}
     *
     * @stability stable
     */
    readonly emr?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#emrcontainers AwsProvider#emrcontainers}
     *
     * @stability stable
     */
    readonly emrcontainers?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#es AwsProvider#es}
     *
     * @stability stable
     */
    readonly es?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#firehose AwsProvider#firehose}
     *
     * @stability stable
     */
    readonly firehose?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#fms AwsProvider#fms}
     *
     * @stability stable
     */
    readonly fms?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#forecast AwsProvider#forecast}
     *
     * @stability stable
     */
    readonly forecast?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#fsx AwsProvider#fsx}
     *
     * @stability stable
     */
    readonly fsx?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#gamelift AwsProvider#gamelift}
     *
     * @stability stable
     */
    readonly gamelift?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#glacier AwsProvider#glacier}
     *
     * @stability stable
     */
    readonly glacier?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#globalaccelerator AwsProvider#globalaccelerator}
     *
     * @stability stable
     */
    readonly globalaccelerator?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#glue AwsProvider#glue}
     *
     * @stability stable
     */
    readonly glue?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#greengrass AwsProvider#greengrass}
     *
     * @stability stable
     */
    readonly greengrass?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#guardduty AwsProvider#guardduty}
     *
     * @stability stable
     */
    readonly guardduty?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#iam AwsProvider#iam}
     *
     * @stability stable
     */
    readonly iam?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#identitystore AwsProvider#identitystore}
     *
     * @stability stable
     */
    readonly identitystore?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#imagebuilder AwsProvider#imagebuilder}
     *
     * @stability stable
     */
    readonly imagebuilder?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#inspector AwsProvider#inspector}
     *
     * @stability stable
     */
    readonly inspector?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#iot AwsProvider#iot}
     *
     * @stability stable
     */
    readonly iot?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#iotanalytics AwsProvider#iotanalytics}
     *
     * @stability stable
     */
    readonly iotanalytics?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#iotevents AwsProvider#iotevents}
     *
     * @stability stable
     */
    readonly iotevents?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#kafka AwsProvider#kafka}
     *
     * @stability stable
     */
    readonly kafka?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#kinesis AwsProvider#kinesis}
     *
     * @stability stable
     */
    readonly kinesis?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#kinesisanalytics AwsProvider#kinesisanalytics}
     *
     * @stability stable
     */
    readonly kinesisanalytics?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#kinesisanalyticsv2 AwsProvider#kinesisanalyticsv2}
     *
     * @stability stable
     */
    readonly kinesisanalyticsv2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#kinesisvideo AwsProvider#kinesisvideo}
     *
     * @stability stable
     */
    readonly kinesisvideo?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#kms AwsProvider#kms}
     *
     * @stability stable
     */
    readonly kms?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#lakeformation AwsProvider#lakeformation}
     *
     * @stability stable
     */
    readonly lakeformation?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#lambda AwsProvider#lambda}
     *
     * @stability stable
     */
    readonly lambda?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#lexmodels AwsProvider#lexmodels}
     *
     * @stability stable
     */
    readonly lexmodels?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#licensemanager AwsProvider#licensemanager}
     *
     * @stability stable
     */
    readonly licensemanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#lightsail AwsProvider#lightsail}
     *
     * @stability stable
     */
    readonly lightsail?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#location AwsProvider#location}
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#macie AwsProvider#macie}
     *
     * @stability stable
     */
    readonly macie?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#macie2 AwsProvider#macie2}
     *
     * @stability stable
     */
    readonly macie2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#managedblockchain AwsProvider#managedblockchain}
     *
     * @stability stable
     */
    readonly managedblockchain?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#marketplacecatalog AwsProvider#marketplacecatalog}
     *
     * @stability stable
     */
    readonly marketplacecatalog?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mediaconnect AwsProvider#mediaconnect}
     *
     * @stability stable
     */
    readonly mediaconnect?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mediaconvert AwsProvider#mediaconvert}
     *
     * @stability stable
     */
    readonly mediaconvert?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#medialive AwsProvider#medialive}
     *
     * @stability stable
     */
    readonly medialive?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mediapackage AwsProvider#mediapackage}
     *
     * @stability stable
     */
    readonly mediapackage?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mediastore AwsProvider#mediastore}
     *
     * @stability stable
     */
    readonly mediastore?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mediastoredata AwsProvider#mediastoredata}
     *
     * @stability stable
     */
    readonly mediastoredata?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#memorydb AwsProvider#memorydb}
     *
     * @stability stable
     */
    readonly memorydb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mq AwsProvider#mq}
     *
     * @stability stable
     */
    readonly mq?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#mwaa AwsProvider#mwaa}
     *
     * @stability stable
     */
    readonly mwaa?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#neptune AwsProvider#neptune}
     *
     * @stability stable
     */
    readonly neptune?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#networkfirewall AwsProvider#networkfirewall}
     *
     * @stability stable
     */
    readonly networkfirewall?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#networkmanager AwsProvider#networkmanager}
     *
     * @stability stable
     */
    readonly networkmanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#opsworks AwsProvider#opsworks}
     *
     * @stability stable
     */
    readonly opsworks?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#organizations AwsProvider#organizations}
     *
     * @stability stable
     */
    readonly organizations?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#outposts AwsProvider#outposts}
     *
     * @stability stable
     */
    readonly outposts?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#personalize AwsProvider#personalize}
     *
     * @stability stable
     */
    readonly personalize?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#pinpoint AwsProvider#pinpoint}
     *
     * @stability stable
     */
    readonly pinpoint?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#pricing AwsProvider#pricing}
     *
     * @stability stable
     */
    readonly pricing?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#qldb AwsProvider#qldb}
     *
     * @stability stable
     */
    readonly qldb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#quicksight AwsProvider#quicksight}
     *
     * @stability stable
     */
    readonly quicksight?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ram AwsProvider#ram}
     *
     * @stability stable
     */
    readonly ram?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#rds AwsProvider#rds}
     *
     * @stability stable
     */
    readonly rds?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#redshift AwsProvider#redshift}
     *
     * @stability stable
     */
    readonly redshift?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#resourcegroups AwsProvider#resourcegroups}
     *
     * @stability stable
     */
    readonly resourcegroups?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#resourcegroupstaggingapi AwsProvider#resourcegroupstaggingapi}
     *
     * @stability stable
     */
    readonly resourcegroupstaggingapi?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#route53 AwsProvider#route53}
     *
     * @stability stable
     */
    readonly route53?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#route53domains AwsProvider#route53domains}
     *
     * @stability stable
     */
    readonly route53Domains?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#route53recoverycontrolconfig AwsProvider#route53recoverycontrolconfig}
     *
     * @stability stable
     */
    readonly route53Recoverycontrolconfig?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#route53recoveryreadiness AwsProvider#route53recoveryreadiness}
     *
     * @stability stable
     */
    readonly route53Recoveryreadiness?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#route53resolver AwsProvider#route53resolver}
     *
     * @stability stable
     */
    readonly route53Resolver?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#s3 AwsProvider#s3}
     *
     * @stability stable
     */
    readonly s3?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#s3control AwsProvider#s3control}
     *
     * @stability stable
     */
    readonly s3Control?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#s3outposts AwsProvider#s3outposts}
     *
     * @stability stable
     */
    readonly s3Outposts?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#sagemaker AwsProvider#sagemaker}
     *
     * @stability stable
     */
    readonly sagemaker?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#schemas AwsProvider#schemas}
     *
     * @stability stable
     */
    readonly schemas?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#sdb AwsProvider#sdb}
     *
     * @stability stable
     */
    readonly sdb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#secretsmanager AwsProvider#secretsmanager}
     *
     * @stability stable
     */
    readonly secretsmanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#securityhub AwsProvider#securityhub}
     *
     * @stability stable
     */
    readonly securityhub?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#serverlessrepo AwsProvider#serverlessrepo}
     *
     * @stability stable
     */
    readonly serverlessrepo?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#servicecatalog AwsProvider#servicecatalog}
     *
     * @stability stable
     */
    readonly servicecatalog?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#servicediscovery AwsProvider#servicediscovery}
     *
     * @stability stable
     */
    readonly servicediscovery?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#servicequotas AwsProvider#servicequotas}
     *
     * @stability stable
     */
    readonly servicequotas?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ses AwsProvider#ses}
     *
     * @stability stable
     */
    readonly ses?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#shield AwsProvider#shield}
     *
     * @stability stable
     */
    readonly shield?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#signer AwsProvider#signer}
     *
     * @stability stable
     */
    readonly signer?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#sns AwsProvider#sns}
     *
     * @stability stable
     */
    readonly sns?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#sqs AwsProvider#sqs}
     *
     * @stability stable
     */
    readonly sqs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ssm AwsProvider#ssm}
     *
     * @stability stable
     */
    readonly ssm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#ssoadmin AwsProvider#ssoadmin}
     *
     * @stability stable
     */
    readonly ssoadmin?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#stepfunctions AwsProvider#stepfunctions}
     *
     * @stability stable
     */
    readonly stepfunctions?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#storagegateway AwsProvider#storagegateway}
     *
     * @stability stable
     */
    readonly storagegateway?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#sts AwsProvider#sts}
     *
     * @stability stable
     */
    readonly sts?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#swf AwsProvider#swf}
     *
     * @stability stable
     */
    readonly swf?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#synthetics AwsProvider#synthetics}
     *
     * @stability stable
     */
    readonly synthetics?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#timestreamwrite AwsProvider#timestreamwrite}
     *
     * @stability stable
     */
    readonly timestreamwrite?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#transfer AwsProvider#transfer}
     *
     * @stability stable
     */
    readonly transfer?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#waf AwsProvider#waf}
     *
     * @stability stable
     */
    readonly waf?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#wafregional AwsProvider#wafregional}
     *
     * @stability stable
     */
    readonly wafregional?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#wafv2 AwsProvider#wafv2}
     *
     * @stability stable
     */
    readonly wafv2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#worklink AwsProvider#worklink}
     *
     * @stability stable
     */
    readonly worklink?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#workmail AwsProvider#workmail}
     *
     * @stability stable
     */
    readonly workmail?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#workspaces AwsProvider#workspaces}
     *
     * @stability stable
     */
    readonly workspaces?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#xray AwsProvider#xray}
     *
     * @stability stable
     */
    readonly xray?: string;
}
/**
 * @stability stable
 */
export interface AwsProviderIgnoreTags {
    /**
     * Resource tag key prefixes to ignore across all resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#key_prefixes AwsProvider#key_prefixes}
     *
     * @stability stable
     */
    readonly keyPrefixes?: string[];
    /**
     * Resource tag keys to ignore across all resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws#keys AwsProvider#keys}
     *
     * @stability stable
     */
    readonly keys?: string[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws aws}.
 *
 * @stability stable
 */
export declare class AwsProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws aws} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AwsProviderConfig);
    private _accessKey?;
    /**
     * @stability stable
     */
    get accessKey(): string | undefined;
    /**
     * @stability stable
     */
    set accessKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetAccessKey(): void;
    /**
     * @stability stable
     */
    get accessKeyInput(): string | undefined;
    private _allowedAccountIds?;
    /**
     * @stability stable
     */
    get allowedAccountIds(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedAccountIds(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedAccountIds(): void;
    /**
     * @stability stable
     */
    get allowedAccountIdsInput(): string[] | undefined;
    private _forbiddenAccountIds?;
    /**
     * @stability stable
     */
    get forbiddenAccountIds(): string[] | undefined;
    /**
     * @stability stable
     */
    set forbiddenAccountIds(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetForbiddenAccountIds(): void;
    /**
     * @stability stable
     */
    get forbiddenAccountIdsInput(): string[] | undefined;
    private _httpProxy?;
    /**
     * @stability stable
     */
    get httpProxy(): string | undefined;
    /**
     * @stability stable
     */
    set httpProxy(value: string | undefined);
    /**
     * @stability stable
     */
    resetHttpProxy(): void;
    /**
     * @stability stable
     */
    get httpProxyInput(): string | undefined;
    private _insecure?;
    /**
     * @stability stable
     */
    get insecure(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set insecure(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetInsecure(): void;
    /**
     * @stability stable
     */
    get insecureInput(): boolean | cdktf.IResolvable | undefined;
    private _maxRetries?;
    /**
     * @stability stable
     */
    get maxRetries(): number | undefined;
    /**
     * @stability stable
     */
    set maxRetries(value: number | undefined);
    /**
     * @stability stable
     */
    resetMaxRetries(): void;
    /**
     * @stability stable
     */
    get maxRetriesInput(): number | undefined;
    private _profile?;
    /**
     * @stability stable
     */
    get profile(): string | undefined;
    /**
     * @stability stable
     */
    set profile(value: string | undefined);
    /**
     * @stability stable
     */
    resetProfile(): void;
    /**
     * @stability stable
     */
    get profileInput(): string | undefined;
    private _region;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    get regionInput(): string;
    private _s3ForcePathStyle?;
    /**
     * @stability stable
     */
    get s3ForcePathStyle(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set s3ForcePathStyle(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetS3ForcePathStyle(): void;
    /**
     * @stability stable
     */
    get s3ForcePathStyleInput(): boolean | cdktf.IResolvable | undefined;
    private _secretKey?;
    /**
     * @stability stable
     */
    get secretKey(): string | undefined;
    /**
     * @stability stable
     */
    set secretKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetSecretKey(): void;
    /**
     * @stability stable
     */
    get secretKeyInput(): string | undefined;
    private _sharedCredentialsFile?;
    /**
     * @stability stable
     */
    get sharedCredentialsFile(): string | undefined;
    /**
     * @stability stable
     */
    set sharedCredentialsFile(value: string | undefined);
    /**
     * @stability stable
     */
    resetSharedCredentialsFile(): void;
    /**
     * @stability stable
     */
    get sharedCredentialsFileInput(): string | undefined;
    private _skipCredentialsValidation?;
    /**
     * @stability stable
     */
    get skipCredentialsValidation(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set skipCredentialsValidation(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSkipCredentialsValidation(): void;
    /**
     * @stability stable
     */
    get skipCredentialsValidationInput(): boolean | cdktf.IResolvable | undefined;
    private _skipGetEc2Platforms?;
    /**
     * @stability stable
     */
    get skipGetEc2Platforms(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set skipGetEc2Platforms(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSkipGetEc2Platforms(): void;
    /**
     * @stability stable
     */
    get skipGetEc2PlatformsInput(): boolean | cdktf.IResolvable | undefined;
    private _skipMetadataApiCheck?;
    /**
     * @stability stable
     */
    get skipMetadataApiCheck(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set skipMetadataApiCheck(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSkipMetadataApiCheck(): void;
    /**
     * @stability stable
     */
    get skipMetadataApiCheckInput(): boolean | cdktf.IResolvable | undefined;
    private _skipRegionValidation?;
    /**
     * @stability stable
     */
    get skipRegionValidation(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set skipRegionValidation(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSkipRegionValidation(): void;
    /**
     * @stability stable
     */
    get skipRegionValidationInput(): boolean | cdktf.IResolvable | undefined;
    private _skipRequestingAccountId?;
    /**
     * @stability stable
     */
    get skipRequestingAccountId(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set skipRequestingAccountId(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSkipRequestingAccountId(): void;
    /**
     * @stability stable
     */
    get skipRequestingAccountIdInput(): boolean | cdktf.IResolvable | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _assumeRole?;
    /**
     * @stability stable
     */
    get assumeRole(): AwsProviderAssumeRole[] | undefined;
    /**
     * @stability stable
     */
    set assumeRole(value: AwsProviderAssumeRole[] | undefined);
    /**
     * @stability stable
     */
    resetAssumeRole(): void;
    /**
     * @stability stable
     */
    get assumeRoleInput(): AwsProviderAssumeRole[] | undefined;
    private _defaultTags?;
    /**
     * @stability stable
     */
    get defaultTags(): AwsProviderDefaultTags[] | undefined;
    /**
     * @stability stable
     */
    set defaultTags(value: AwsProviderDefaultTags[] | undefined);
    /**
     * @stability stable
     */
    resetDefaultTags(): void;
    /**
     * @stability stable
     */
    get defaultTagsInput(): AwsProviderDefaultTags[] | undefined;
    private _endpoints?;
    /**
     * @stability stable
     */
    get endpoints(): AwsProviderEndpoints[] | undefined;
    /**
     * @stability stable
     */
    set endpoints(value: AwsProviderEndpoints[] | undefined);
    /**
     * @stability stable
     */
    resetEndpoints(): void;
    /**
     * @stability stable
     */
    get endpointsInput(): AwsProviderEndpoints[] | undefined;
    private _ignoreTags?;
    /**
     * @stability stable
     */
    get ignoreTags(): AwsProviderIgnoreTags[] | undefined;
    /**
     * @stability stable
     */
    set ignoreTags(value: AwsProviderIgnoreTags[] | undefined);
    /**
     * @stability stable
     */
    resetIgnoreTags(): void;
    /**
     * @stability stable
     */
    get ignoreTagsInput(): AwsProviderIgnoreTags[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
