import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudformationStackSetInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#account_id CloudformationStackSetInstance#account_id}.
     *
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#parameter_overrides CloudformationStackSetInstance#parameter_overrides}.
     *
     * @stability stable
     */
    readonly parameterOverrides?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#region CloudformationStackSetInstance#region}.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#retain_stack CloudformationStackSetInstance#retain_stack}.
     *
     * @stability stable
     */
    readonly retainStack?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#stack_set_name CloudformationStackSetInstance#stack_set_name}.
     *
     * @stability stable
     */
    readonly stackSetName: string;
    /**
     * deployment_targets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#deployment_targets CloudformationStackSetInstance#deployment_targets}
     *
     * @stability stable
     */
    readonly deploymentTargets?: CloudformationStackSetInstanceDeploymentTargets[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#timeouts CloudformationStackSetInstance#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CloudformationStackSetInstanceTimeouts;
}
/**
 * @stability stable
 */
export interface CloudformationStackSetInstanceDeploymentTargets {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#organizational_unit_ids CloudformationStackSetInstance#organizational_unit_ids}.
     *
     * @stability stable
     */
    readonly organizationalUnitIds?: string[];
}
/**
 * @stability stable
 */
export interface CloudformationStackSetInstanceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#create CloudformationStackSetInstance#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#delete CloudformationStackSetInstance#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#update CloudformationStackSetInstance#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html aws_cloudformation_stack_set_instance}.
 *
 * @stability stable
 */
export declare class CloudformationStackSetInstance extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html aws_cloudformation_stack_set_instance} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudformationStackSetInstanceConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    set accountId(value: string);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get organizationalUnitId(): string;
    private _parameterOverrides?;
    /**
     * @stability stable
     */
    get parameterOverrides(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set parameterOverrides(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetParameterOverrides(): void;
    /**
     * @stability stable
     */
    get parameterOverridesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _retainStack?;
    /**
     * @stability stable
     */
    get retainStack(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set retainStack(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRetainStack(): void;
    /**
     * @stability stable
     */
    get retainStackInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get stackId(): string;
    private _stackSetName;
    /**
     * @stability stable
     */
    get stackSetName(): string;
    /**
     * @stability stable
     */
    set stackSetName(value: string);
    /**
     * @stability stable
     */
    get stackSetNameInput(): string;
    private _deploymentTargets?;
    /**
     * @stability stable
     */
    get deploymentTargets(): CloudformationStackSetInstanceDeploymentTargets[];
    /**
     * @stability stable
     */
    set deploymentTargets(value: CloudformationStackSetInstanceDeploymentTargets[]);
    /**
     * @stability stable
     */
    resetDeploymentTargets(): void;
    /**
     * @stability stable
     */
    get deploymentTargetsInput(): CloudformationStackSetInstanceDeploymentTargets[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudformationStackSetInstanceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudformationStackSetInstanceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudformationStackSetInstanceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
