import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudformationTypeConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#execution_role_arn CloudformationType#execution_role_arn}.
     *
     * @stability stable
     */
    readonly executionRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#schema_handler_package CloudformationType#schema_handler_package}.
     *
     * @stability stable
     */
    readonly schemaHandlerPackage: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#type CloudformationType#type}.
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#type_name CloudformationType#type_name}.
     *
     * @stability stable
     */
    readonly typeName: string;
    /**
     * logging_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#logging_config CloudformationType#logging_config}
     *
     * @stability stable
     */
    readonly loggingConfig?: CloudformationTypeLoggingConfig[];
}
/**
 * @stability stable
 */
export interface CloudformationTypeLoggingConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#log_group_name CloudformationType#log_group_name}.
     *
     * @stability stable
     */
    readonly logGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#log_role_arn CloudformationType#log_role_arn}.
     *
     * @stability stable
     */
    readonly logRoleArn: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html aws_cloudformation_type}.
 *
 * @stability stable
 */
export declare class CloudformationType extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html aws_cloudformation_type} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudformationTypeConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get defaultVersionId(): string;
    /**
     * @stability stable
     */
    get deprecatedStatus(): string;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get documentationUrl(): string;
    private _executionRoleArn?;
    /**
     * @stability stable
     */
    get executionRoleArn(): string;
    /**
     * @stability stable
     */
    set executionRoleArn(value: string);
    /**
     * @stability stable
     */
    resetExecutionRoleArn(): void;
    /**
     * @stability stable
     */
    get executionRoleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get isDefaultVersion(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get provisioningType(): string;
    /**
     * @stability stable
     */
    get schema(): string;
    private _schemaHandlerPackage;
    /**
     * @stability stable
     */
    get schemaHandlerPackage(): string;
    /**
     * @stability stable
     */
    set schemaHandlerPackage(value: string);
    /**
     * @stability stable
     */
    get schemaHandlerPackageInput(): string;
    /**
     * @stability stable
     */
    get sourceUrl(): string;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    /**
     * @stability stable
     */
    get typeArn(): string;
    private _typeName;
    /**
     * @stability stable
     */
    get typeName(): string;
    /**
     * @stability stable
     */
    set typeName(value: string);
    /**
     * @stability stable
     */
    get typeNameInput(): string;
    /**
     * @stability stable
     */
    get versionId(): string;
    /**
     * @stability stable
     */
    get visibility(): string;
    private _loggingConfig?;
    /**
     * @stability stable
     */
    get loggingConfig(): CloudformationTypeLoggingConfig[];
    /**
     * @stability stable
     */
    set loggingConfig(value: CloudformationTypeLoggingConfig[]);
    /**
     * @stability stable
     */
    resetLoggingConfig(): void;
    /**
     * @stability stable
     */
    get loggingConfigInput(): CloudformationTypeLoggingConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
