import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudhsmV2ClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#hsm_type CloudhsmV2Cluster#hsm_type}.
     *
     * @stability stable
     */
    readonly hsmType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#source_backup_identifier CloudhsmV2Cluster#source_backup_identifier}.
     *
     * @stability stable
     */
    readonly sourceBackupIdentifier?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#subnet_ids CloudhsmV2Cluster#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#tags CloudhsmV2Cluster#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#tags_all CloudhsmV2Cluster#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#timeouts CloudhsmV2Cluster#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CloudhsmV2ClusterTimeouts;
}
/**
 * @stability stable
 */
export declare class CloudhsmV2ClusterClusterCertificates extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get awsHardwareCertificate(): string;
    /**
     * @stability stable
     */
    get clusterCertificate(): string;
    /**
     * @stability stable
     */
    get clusterCsr(): string;
    /**
     * @stability stable
     */
    get hsmCertificate(): string;
    /**
     * @stability stable
     */
    get manufacturerHardwareCertificate(): string;
}
/**
 * @stability stable
 */
export interface CloudhsmV2ClusterTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#create CloudhsmV2Cluster#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#delete CloudhsmV2Cluster#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#update CloudhsmV2Cluster#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html aws_cloudhsm_v2_cluster}.
 *
 * @stability stable
 */
export declare class CloudhsmV2Cluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html aws_cloudhsm_v2_cluster} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudhsmV2ClusterConfig);
    /**
     * @stability stable
     */
    clusterCertificates(index: string): CloudhsmV2ClusterClusterCertificates;
    /**
     * @stability stable
     */
    get clusterId(): string;
    /**
     * @stability stable
     */
    get clusterState(): string;
    private _hsmType;
    /**
     * @stability stable
     */
    get hsmType(): string;
    /**
     * @stability stable
     */
    set hsmType(value: string);
    /**
     * @stability stable
     */
    get hsmTypeInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get securityGroupId(): string;
    private _sourceBackupIdentifier?;
    /**
     * @stability stable
     */
    get sourceBackupIdentifier(): string;
    /**
     * @stability stable
     */
    set sourceBackupIdentifier(value: string);
    /**
     * @stability stable
     */
    resetSourceBackupIdentifier(): void;
    /**
     * @stability stable
     */
    get sourceBackupIdentifierInput(): string | undefined;
    private _subnetIds;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[];
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudhsmV2ClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudhsmV2ClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudhsmV2ClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
