import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CodepipelineWebhookConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#authentication CodepipelineWebhook#authentication}.
     *
     * @stability stable
     */
    readonly authentication: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#name CodepipelineWebhook#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#tags CodepipelineWebhook#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#tags_all CodepipelineWebhook#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#target_action CodepipelineWebhook#target_action}.
     *
     * @stability stable
     */
    readonly targetAction: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#target_pipeline CodepipelineWebhook#target_pipeline}.
     *
     * @stability stable
     */
    readonly targetPipeline: string;
    /**
     * authentication_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#authentication_configuration CodepipelineWebhook#authentication_configuration}
     *
     * @stability stable
     */
    readonly authenticationConfiguration?: CodepipelineWebhookAuthenticationConfiguration[];
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#filter CodepipelineWebhook#filter}
     *
     * @stability stable
     */
    readonly filter: CodepipelineWebhookFilter[];
}
/**
 * @stability stable
 */
export interface CodepipelineWebhookAuthenticationConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#allowed_ip_range CodepipelineWebhook#allowed_ip_range}.
     *
     * @stability stable
     */
    readonly allowedIpRange?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#secret_token CodepipelineWebhook#secret_token}.
     *
     * @stability stable
     */
    readonly secretToken?: string;
}
/**
 * @stability stable
 */
export interface CodepipelineWebhookFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#json_path CodepipelineWebhook#json_path}.
     *
     * @stability stable
     */
    readonly jsonPath: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#match_equals CodepipelineWebhook#match_equals}.
     *
     * @stability stable
     */
    readonly matchEquals: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html aws_codepipeline_webhook}.
 *
 * @stability stable
 */
export declare class CodepipelineWebhook extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html aws_codepipeline_webhook} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CodepipelineWebhookConfig);
    private _authentication;
    /**
     * @stability stable
     */
    get authentication(): string;
    /**
     * @stability stable
     */
    set authentication(value: string);
    /**
     * @stability stable
     */
    get authenticationInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _targetAction;
    /**
     * @stability stable
     */
    get targetAction(): string;
    /**
     * @stability stable
     */
    set targetAction(value: string);
    /**
     * @stability stable
     */
    get targetActionInput(): string;
    private _targetPipeline;
    /**
     * @stability stable
     */
    get targetPipeline(): string;
    /**
     * @stability stable
     */
    set targetPipeline(value: string);
    /**
     * @stability stable
     */
    get targetPipelineInput(): string;
    /**
     * @stability stable
     */
    get url(): string;
    private _authenticationConfiguration?;
    /**
     * @stability stable
     */
    get authenticationConfiguration(): CodepipelineWebhookAuthenticationConfiguration[];
    /**
     * @stability stable
     */
    set authenticationConfiguration(value: CodepipelineWebhookAuthenticationConfiguration[]);
    /**
     * @stability stable
     */
    resetAuthenticationConfiguration(): void;
    /**
     * @stability stable
     */
    get authenticationConfigurationInput(): CodepipelineWebhookAuthenticationConfiguration[] | undefined;
    private _filter;
    /**
     * @stability stable
     */
    get filter(): CodepipelineWebhookFilter[];
    /**
     * @stability stable
     */
    set filter(value: CodepipelineWebhookFilter[]);
    /**
     * @stability stable
     */
    get filterInput(): CodepipelineWebhookFilter[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
