import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DbProxyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#debug_logging DbProxy#debug_logging}.
     *
     * @stability stable
     */
    readonly debugLogging?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#engine_family DbProxy#engine_family}.
     *
     * @stability stable
     */
    readonly engineFamily: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#idle_client_timeout DbProxy#idle_client_timeout}.
     *
     * @stability stable
     */
    readonly idleClientTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#name DbProxy#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#require_tls DbProxy#require_tls}.
     *
     * @stability stable
     */
    readonly requireTls?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#role_arn DbProxy#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#tags DbProxy#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#tags_all DbProxy#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#vpc_security_group_ids DbProxy#vpc_security_group_ids}.
     *
     * @stability stable
     */
    readonly vpcSecurityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#vpc_subnet_ids DbProxy#vpc_subnet_ids}.
     *
     * @stability stable
     */
    readonly vpcSubnetIds: string[];
    /**
     * auth block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#auth DbProxy#auth}
     *
     * @stability stable
     */
    readonly auth: DbProxyAuth[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#timeouts DbProxy#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DbProxyTimeouts;
}
/**
 * @stability stable
 */
export interface DbProxyAuth {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#auth_scheme DbProxy#auth_scheme}.
     *
     * @stability stable
     */
    readonly authScheme?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#description DbProxy#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#iam_auth DbProxy#iam_auth}.
     *
     * @stability stable
     */
    readonly iamAuth?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#secret_arn DbProxy#secret_arn}.
     *
     * @stability stable
     */
    readonly secretArn?: string;
}
/**
 * @stability stable
 */
export interface DbProxyTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#create DbProxy#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#delete DbProxy#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#update DbProxy#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html aws_db_proxy}.
 *
 * @stability stable
 */
export declare class DbProxy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html aws_db_proxy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DbProxyConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _debugLogging?;
    /**
     * @stability stable
     */
    get debugLogging(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set debugLogging(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDebugLogging(): void;
    /**
     * @stability stable
     */
    get debugLoggingInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    private _engineFamily;
    /**
     * @stability stable
     */
    get engineFamily(): string;
    /**
     * @stability stable
     */
    set engineFamily(value: string);
    /**
     * @stability stable
     */
    get engineFamilyInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _idleClientTimeout?;
    /**
     * @stability stable
     */
    get idleClientTimeout(): number;
    /**
     * @stability stable
     */
    set idleClientTimeout(value: number);
    /**
     * @stability stable
     */
    resetIdleClientTimeout(): void;
    /**
     * @stability stable
     */
    get idleClientTimeoutInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _requireTls?;
    /**
     * @stability stable
     */
    get requireTls(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requireTls(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequireTls(): void;
    /**
     * @stability stable
     */
    get requireTlsInput(): boolean | cdktf.IResolvable | undefined;
    private _roleArn;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _vpcSecurityGroupIds?;
    /**
     * @stability stable
     */
    get vpcSecurityGroupIds(): string[];
    /**
     * @stability stable
     */
    set vpcSecurityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetVpcSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get vpcSecurityGroupIdsInput(): string[] | undefined;
    private _vpcSubnetIds;
    /**
     * @stability stable
     */
    get vpcSubnetIds(): string[];
    /**
     * @stability stable
     */
    set vpcSubnetIds(value: string[]);
    /**
     * @stability stable
     */
    get vpcSubnetIdsInput(): string[];
    private _auth;
    /**
     * @stability stable
     */
    get auth(): DbProxyAuth[];
    /**
     * @stability stable
     */
    set auth(value: DbProxyAuth[]);
    /**
     * @stability stable
     */
    get authInput(): DbProxyAuth[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DbProxyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DbProxyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DbProxyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
