import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DbSnapshotConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#db_instance_identifier DbSnapshot#db_instance_identifier}.
     *
     * @stability stable
     */
    readonly dbInstanceIdentifier: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#db_snapshot_identifier DbSnapshot#db_snapshot_identifier}.
     *
     * @stability stable
     */
    readonly dbSnapshotIdentifier: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#tags DbSnapshot#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#tags_all DbSnapshot#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#timeouts DbSnapshot#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DbSnapshotTimeouts;
}
/**
 * @stability stable
 */
export interface DbSnapshotTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#read DbSnapshot#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html aws_db_snapshot}.
 *
 * @stability stable
 */
export declare class DbSnapshot extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html aws_db_snapshot} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DbSnapshotConfig);
    /**
     * @stability stable
     */
    get allocatedStorage(): number;
    /**
     * @stability stable
     */
    get availabilityZone(): string;
    private _dbInstanceIdentifier;
    /**
     * @stability stable
     */
    get dbInstanceIdentifier(): string;
    /**
     * @stability stable
     */
    set dbInstanceIdentifier(value: string);
    /**
     * @stability stable
     */
    get dbInstanceIdentifierInput(): string;
    /**
     * @stability stable
     */
    get dbSnapshotArn(): string;
    private _dbSnapshotIdentifier;
    /**
     * @stability stable
     */
    get dbSnapshotIdentifier(): string;
    /**
     * @stability stable
     */
    set dbSnapshotIdentifier(value: string);
    /**
     * @stability stable
     */
    get dbSnapshotIdentifierInput(): string;
    /**
     * @stability stable
     */
    get encrypted(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get engine(): string;
    /**
     * @stability stable
     */
    get engineVersion(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get iops(): number;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    get licenseModel(): string;
    /**
     * @stability stable
     */
    get optionGroupName(): string;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    get snapshotType(): string;
    /**
     * @stability stable
     */
    get sourceDbSnapshotIdentifier(): string;
    /**
     * @stability stable
     */
    get sourceRegion(): string;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    get storageType(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DbSnapshotTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DbSnapshotTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DbSnapshotTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
