import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DefaultSubnetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#availability_zone DefaultSubnet#availability_zone}.
     *
     * @stability stable
     */
    readonly availabilityZone: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#customer_owned_ipv4_pool DefaultSubnet#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#map_customer_owned_ip_on_launch DefaultSubnet#map_customer_owned_ip_on_launch}.
     *
     * @stability stable
     */
    readonly mapCustomerOwnedIpOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#map_public_ip_on_launch DefaultSubnet#map_public_ip_on_launch}.
     *
     * @stability stable
     */
    readonly mapPublicIpOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#outpost_arn DefaultSubnet#outpost_arn}.
     *
     * @stability stable
     */
    readonly outpostArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#tags DefaultSubnet#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#tags_all DefaultSubnet#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#timeouts DefaultSubnet#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DefaultSubnetTimeouts;
}
/**
 * @stability stable
 */
export interface DefaultSubnetTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#create DefaultSubnet#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#delete DefaultSubnet#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html aws_default_subnet}.
 *
 * @stability stable
 */
export declare class DefaultSubnet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html aws_default_subnet} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DefaultSubnetConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get assignIpv6AddressOnCreation(): cdktf.IResolvable;
    private _availabilityZone;
    /**
     * @stability stable
     */
    get availabilityZone(): string;
    /**
     * @stability stable
     */
    set availabilityZone(value: string);
    /**
     * @stability stable
     */
    get availabilityZoneInput(): string;
    /**
     * @stability stable
     */
    get availabilityZoneId(): string;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ipv6CidrBlock(): string;
    /**
     * @stability stable
     */
    get ipv6CidrBlockAssociationId(): string;
    private _mapCustomerOwnedIpOnLaunch?;
    /**
     * @stability stable
     */
    get mapCustomerOwnedIpOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mapCustomerOwnedIpOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMapCustomerOwnedIpOnLaunch(): void;
    /**
     * @stability stable
     */
    get mapCustomerOwnedIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _mapPublicIpOnLaunch?;
    /**
     * @stability stable
     */
    get mapPublicIpOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mapPublicIpOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMapPublicIpOnLaunch(): void;
    /**
     * @stability stable
     */
    get mapPublicIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _outpostArn?;
    /**
     * @stability stable
     */
    get outpostArn(): string;
    /**
     * @stability stable
     */
    set outpostArn(value: string);
    /**
     * @stability stable
     */
    resetOutpostArn(): void;
    /**
     * @stability stable
     */
    get outpostArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DefaultSubnetTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DefaultSubnetTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DefaultSubnetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
