import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DefaultVpcConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_classiclink DefaultVpc#enable_classiclink}.
     *
     * @stability stable
     */
    readonly enableClassiclink?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_classiclink_dns_support DefaultVpc#enable_classiclink_dns_support}.
     *
     * @stability stable
     */
    readonly enableClassiclinkDnsSupport?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_dns_hostnames DefaultVpc#enable_dns_hostnames}.
     *
     * @stability stable
     */
    readonly enableDnsHostnames?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_dns_support DefaultVpc#enable_dns_support}.
     *
     * @stability stable
     */
    readonly enableDnsSupport?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#tags DefaultVpc#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#tags_all DefaultVpc#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html aws_default_vpc}.
 *
 * @stability stable
 */
export declare class DefaultVpc extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html aws_default_vpc} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DefaultVpcConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get assignGeneratedIpv6CidrBlock(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    /**
     * @stability stable
     */
    get defaultNetworkAclId(): string;
    /**
     * @stability stable
     */
    get defaultRouteTableId(): string;
    /**
     * @stability stable
     */
    get defaultSecurityGroupId(): string;
    /**
     * @stability stable
     */
    get dhcpOptionsId(): string;
    private _enableClassiclink?;
    /**
     * @stability stable
     */
    get enableClassiclink(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableClassiclink(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableClassiclink(): void;
    /**
     * @stability stable
     */
    get enableClassiclinkInput(): boolean | cdktf.IResolvable | undefined;
    private _enableClassiclinkDnsSupport?;
    /**
     * @stability stable
     */
    get enableClassiclinkDnsSupport(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableClassiclinkDnsSupport(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableClassiclinkDnsSupport(): void;
    /**
     * @stability stable
     */
    get enableClassiclinkDnsSupportInput(): boolean | cdktf.IResolvable | undefined;
    private _enableDnsHostnames?;
    /**
     * @stability stable
     */
    get enableDnsHostnames(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableDnsHostnames(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableDnsHostnames(): void;
    /**
     * @stability stable
     */
    get enableDnsHostnamesInput(): boolean | cdktf.IResolvable | undefined;
    private _enableDnsSupport?;
    /**
     * @stability stable
     */
    get enableDnsSupport(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableDnsSupport(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableDnsSupport(): void;
    /**
     * @stability stable
     */
    get enableDnsSupportInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get instanceTenancy(): string;
    /**
     * @stability stable
     */
    get ipv6AssociationId(): string;
    /**
     * @stability stable
     */
    get ipv6CidrBlock(): string;
    /**
     * @stability stable
     */
    get mainRouteTableId(): string;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
