import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EcrRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#image_tag_mutability EcrRepository#image_tag_mutability}.
     *
     * @stability stable
     */
    readonly imageTagMutability?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#name EcrRepository#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#tags EcrRepository#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#tags_all EcrRepository#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * encryption_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#encryption_configuration EcrRepository#encryption_configuration}
     *
     * @stability stable
     */
    readonly encryptionConfiguration?: EcrRepositoryEncryptionConfiguration[];
    /**
     * image_scanning_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#image_scanning_configuration EcrRepository#image_scanning_configuration}
     *
     * @stability stable
     */
    readonly imageScanningConfiguration?: EcrRepositoryImageScanningConfiguration[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#timeouts EcrRepository#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EcrRepositoryTimeouts;
}
/**
 * @stability stable
 */
export interface EcrRepositoryEncryptionConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#encryption_type EcrRepository#encryption_type}.
     *
     * @stability stable
     */
    readonly encryptionType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#kms_key EcrRepository#kms_key}.
     *
     * @stability stable
     */
    readonly kmsKey?: string;
}
/**
 * @stability stable
 */
export interface EcrRepositoryImageScanningConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#scan_on_push EcrRepository#scan_on_push}.
     *
     * @stability stable
     */
    readonly scanOnPush: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface EcrRepositoryTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#delete EcrRepository#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html aws_ecr_repository}.
 *
 * @stability stable
 */
export declare class EcrRepository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html aws_ecr_repository} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcrRepositoryConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _imageTagMutability?;
    /**
     * @stability stable
     */
    get imageTagMutability(): string;
    /**
     * @stability stable
     */
    set imageTagMutability(value: string);
    /**
     * @stability stable
     */
    resetImageTagMutability(): void;
    /**
     * @stability stable
     */
    get imageTagMutabilityInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get registryId(): string;
    /**
     * @stability stable
     */
    get repositoryUrl(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _encryptionConfiguration?;
    /**
     * @stability stable
     */
    get encryptionConfiguration(): EcrRepositoryEncryptionConfiguration[];
    /**
     * @stability stable
     */
    set encryptionConfiguration(value: EcrRepositoryEncryptionConfiguration[]);
    /**
     * @stability stable
     */
    resetEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get encryptionConfigurationInput(): EcrRepositoryEncryptionConfiguration[] | undefined;
    private _imageScanningConfiguration?;
    /**
     * @stability stable
     */
    get imageScanningConfiguration(): EcrRepositoryImageScanningConfiguration[];
    /**
     * @stability stable
     */
    set imageScanningConfiguration(value: EcrRepositoryImageScanningConfiguration[]);
    /**
     * @stability stable
     */
    resetImageScanningConfiguration(): void;
    /**
     * @stability stable
     */
    get imageScanningConfigurationInput(): EcrRepositoryImageScanningConfiguration[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EcrRepositoryTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EcrRepositoryTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EcrRepositoryTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
