import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EfsAccessPointConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#file_system_id EfsAccessPoint#file_system_id}.
     *
     * @stability stable
     */
    readonly fileSystemId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#tags EfsAccessPoint#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#tags_all EfsAccessPoint#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * posix_user block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#posix_user EfsAccessPoint#posix_user}
     *
     * @stability stable
     */
    readonly posixUser?: EfsAccessPointPosixUser[];
    /**
     * root_directory block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#root_directory EfsAccessPoint#root_directory}
     *
     * @stability stable
     */
    readonly rootDirectory?: EfsAccessPointRootDirectory[];
}
/**
 * @stability stable
 */
export interface EfsAccessPointPosixUser {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#gid EfsAccessPoint#gid}.
     *
     * @stability stable
     */
    readonly gid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#secondary_gids EfsAccessPoint#secondary_gids}.
     *
     * @stability stable
     */
    readonly secondaryGids?: number[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#uid EfsAccessPoint#uid}.
     *
     * @stability stable
     */
    readonly uid: number;
}
/**
 * @stability stable
 */
export interface EfsAccessPointRootDirectoryCreationInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#owner_gid EfsAccessPoint#owner_gid}.
     *
     * @stability stable
     */
    readonly ownerGid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#owner_uid EfsAccessPoint#owner_uid}.
     *
     * @stability stable
     */
    readonly ownerUid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#permissions EfsAccessPoint#permissions}.
     *
     * @stability stable
     */
    readonly permissions: string;
}
/**
 * @stability stable
 */
export interface EfsAccessPointRootDirectory {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#path EfsAccessPoint#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * creation_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#creation_info EfsAccessPoint#creation_info}
     *
     * @stability stable
     */
    readonly creationInfo?: EfsAccessPointRootDirectoryCreationInfo[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html aws_efs_access_point}.
 *
 * @stability stable
 */
export declare class EfsAccessPoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html aws_efs_access_point} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EfsAccessPointConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get fileSystemArn(): string;
    private _fileSystemId;
    /**
     * @stability stable
     */
    get fileSystemId(): string;
    /**
     * @stability stable
     */
    set fileSystemId(value: string);
    /**
     * @stability stable
     */
    get fileSystemIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _posixUser?;
    /**
     * @stability stable
     */
    get posixUser(): EfsAccessPointPosixUser[];
    /**
     * @stability stable
     */
    set posixUser(value: EfsAccessPointPosixUser[]);
    /**
     * @stability stable
     */
    resetPosixUser(): void;
    /**
     * @stability stable
     */
    get posixUserInput(): EfsAccessPointPosixUser[] | undefined;
    private _rootDirectory?;
    /**
     * @stability stable
     */
    get rootDirectory(): EfsAccessPointRootDirectory[];
    /**
     * @stability stable
     */
    set rootDirectory(value: EfsAccessPointRootDirectory[]);
    /**
     * @stability stable
     */
    resetRootDirectory(): void;
    /**
     * @stability stable
     */
    get rootDirectoryInput(): EfsAccessPointRootDirectory[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
