import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EksClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#enabled_cluster_log_types EksCluster#enabled_cluster_log_types}.
     *
     * @stability stable
     */
    readonly enabledClusterLogTypes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#name EksCluster#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#role_arn EksCluster#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#tags EksCluster#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#tags_all EksCluster#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#version EksCluster#version}.
     *
     * @stability stable
     */
    readonly version?: string;
    /**
     * encryption_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#encryption_config EksCluster#encryption_config}
     *
     * @stability stable
     */
    readonly encryptionConfig?: EksClusterEncryptionConfig[];
    /**
     * kubernetes_network_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#kubernetes_network_config EksCluster#kubernetes_network_config}
     *
     * @stability stable
     */
    readonly kubernetesNetworkConfig?: EksClusterKubernetesNetworkConfig[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#timeouts EksCluster#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EksClusterTimeouts;
    /**
     * vpc_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#vpc_config EksCluster#vpc_config}
     *
     * @stability stable
     */
    readonly vpcConfig: EksClusterVpcConfig[];
}
/**
 * @stability stable
 */
export declare class EksClusterCertificateAuthority extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get data(): string;
}
/**
 * @stability stable
 */
export declare class EksClusterIdentityOidc extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get issuer(): string;
}
/**
 * @stability stable
 */
export declare class EksClusterIdentity extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get oidc(): any;
}
/**
 * @stability stable
 */
export interface EksClusterEncryptionConfigProvider {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#key_arn EksCluster#key_arn}.
     *
     * @stability stable
     */
    readonly keyArn: string;
}
/**
 * @stability stable
 */
export interface EksClusterEncryptionConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#resources EksCluster#resources}.
     *
     * @stability stable
     */
    readonly resources: string[];
    /**
     * provider block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#provider EksCluster#provider}
     *
     * @stability stable
     */
    readonly provider: EksClusterEncryptionConfigProvider[];
}
/**
 * @stability stable
 */
export interface EksClusterKubernetesNetworkConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#service_ipv4_cidr EksCluster#service_ipv4_cidr}.
     *
     * @stability stable
     */
    readonly serviceIpv4Cidr?: string;
}
/**
 * @stability stable
 */
export interface EksClusterTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#create EksCluster#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#delete EksCluster#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#update EksCluster#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface EksClusterVpcConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#endpoint_private_access EksCluster#endpoint_private_access}.
     *
     * @stability stable
     */
    readonly endpointPrivateAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#endpoint_public_access EksCluster#endpoint_public_access}.
     *
     * @stability stable
     */
    readonly endpointPublicAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#public_access_cidrs EksCluster#public_access_cidrs}.
     *
     * @stability stable
     */
    readonly publicAccessCidrs?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#security_group_ids EksCluster#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#subnet_ids EksCluster#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds: string[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html aws_eks_cluster}.
 *
 * @stability stable
 */
export declare class EksCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html aws_eks_cluster} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EksClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    certificateAuthority(index: string): EksClusterCertificateAuthority;
    /**
     * @stability stable
     */
    get createdAt(): string;
    private _enabledClusterLogTypes?;
    /**
     * @stability stable
     */
    get enabledClusterLogTypes(): string[];
    /**
     * @stability stable
     */
    set enabledClusterLogTypes(value: string[]);
    /**
     * @stability stable
     */
    resetEnabledClusterLogTypes(): void;
    /**
     * @stability stable
     */
    get enabledClusterLogTypesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    identity(index: string): EksClusterIdentity;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    private _roleArn;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    resetVersion(): void;
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
    private _encryptionConfig?;
    /**
     * @stability stable
     */
    get encryptionConfig(): EksClusterEncryptionConfig[];
    /**
     * @stability stable
     */
    set encryptionConfig(value: EksClusterEncryptionConfig[]);
    /**
     * @stability stable
     */
    resetEncryptionConfig(): void;
    /**
     * @stability stable
     */
    get encryptionConfigInput(): EksClusterEncryptionConfig[] | undefined;
    private _kubernetesNetworkConfig?;
    /**
     * @stability stable
     */
    get kubernetesNetworkConfig(): EksClusterKubernetesNetworkConfig[];
    /**
     * @stability stable
     */
    set kubernetesNetworkConfig(value: EksClusterKubernetesNetworkConfig[]);
    /**
     * @stability stable
     */
    resetKubernetesNetworkConfig(): void;
    /**
     * @stability stable
     */
    get kubernetesNetworkConfigInput(): EksClusterKubernetesNetworkConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EksClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EksClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EksClusterTimeouts | undefined;
    private _vpcConfig;
    /**
     * @stability stable
     */
    get vpcConfig(): EksClusterVpcConfig[];
    /**
     * @stability stable
     */
    set vpcConfig(value: EksClusterVpcConfig[]);
    /**
     * @stability stable
     */
    get vpcConfigInput(): EksClusterVpcConfig[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
