import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GlueConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#catalog_id GlueConnection#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#connection_properties GlueConnection#connection_properties}.
     *
     * @stability stable
     */
    readonly connectionProperties?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#connection_type GlueConnection#connection_type}.
     *
     * @stability stable
     */
    readonly connectionType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#description GlueConnection#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#match_criteria GlueConnection#match_criteria}.
     *
     * @stability stable
     */
    readonly matchCriteria?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#name GlueConnection#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#tags GlueConnection#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#tags_all GlueConnection#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * physical_connection_requirements block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#physical_connection_requirements GlueConnection#physical_connection_requirements}
     *
     * @stability stable
     */
    readonly physicalConnectionRequirements?: GlueConnectionPhysicalConnectionRequirements[];
}
/**
 * @stability stable
 */
export interface GlueConnectionPhysicalConnectionRequirements {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#availability_zone GlueConnection#availability_zone}.
     *
     * @stability stable
     */
    readonly availabilityZone?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#security_group_id_list GlueConnection#security_group_id_list}.
     *
     * @stability stable
     */
    readonly securityGroupIdList?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#subnet_id GlueConnection#subnet_id}.
     *
     * @stability stable
     */
    readonly subnetId?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html aws_glue_connection}.
 *
 * @stability stable
 */
export declare class GlueConnection extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html aws_glue_connection} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GlueConnectionConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _connectionProperties?;
    /**
     * @stability stable
     */
    get connectionProperties(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set connectionProperties(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetConnectionProperties(): void;
    /**
     * @stability stable
     */
    get connectionPropertiesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _connectionType?;
    /**
     * @stability stable
     */
    get connectionType(): string;
    /**
     * @stability stable
     */
    set connectionType(value: string);
    /**
     * @stability stable
     */
    resetConnectionType(): void;
    /**
     * @stability stable
     */
    get connectionTypeInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _matchCriteria?;
    /**
     * @stability stable
     */
    get matchCriteria(): string[];
    /**
     * @stability stable
     */
    set matchCriteria(value: string[]);
    /**
     * @stability stable
     */
    resetMatchCriteria(): void;
    /**
     * @stability stable
     */
    get matchCriteriaInput(): string[] | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _physicalConnectionRequirements?;
    /**
     * @stability stable
     */
    get physicalConnectionRequirements(): GlueConnectionPhysicalConnectionRequirements[];
    /**
     * @stability stable
     */
    set physicalConnectionRequirements(value: GlueConnectionPhysicalConnectionRequirements[]);
    /**
     * @stability stable
     */
    resetPhysicalConnectionRequirements(): void;
    /**
     * @stability stable
     */
    get physicalConnectionRequirementsInput(): GlueConnectionPhysicalConnectionRequirements[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
