import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface LambdaCodeSigningConfigConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#description LambdaCodeSigningConfig#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * allowed_publishers block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#allowed_publishers LambdaCodeSigningConfig#allowed_publishers}
     *
     * @stability stable
     */
    readonly allowedPublishers: LambdaCodeSigningConfigAllowedPublishers[];
    /**
     * policies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#policies LambdaCodeSigningConfig#policies}
     *
     * @stability stable
     */
    readonly policies?: LambdaCodeSigningConfigPolicies[];
}
/**
 * @stability stable
 */
export interface LambdaCodeSigningConfigAllowedPublishers {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#signing_profile_version_arns LambdaCodeSigningConfig#signing_profile_version_arns}.
     *
     * @stability stable
     */
    readonly signingProfileVersionArns: string[];
}
/**
 * @stability stable
 */
export interface LambdaCodeSigningConfigPolicies {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}.
     *
     * @stability stable
     */
    readonly untrustedArtifactOnDeployment: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html aws_lambda_code_signing_config}.
 *
 * @stability stable
 */
export declare class LambdaCodeSigningConfig extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html aws_lambda_code_signing_config} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LambdaCodeSigningConfigConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get configId(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastModified(): string;
    private _allowedPublishers;
    /**
     * @stability stable
     */
    get allowedPublishers(): LambdaCodeSigningConfigAllowedPublishers[];
    /**
     * @stability stable
     */
    set allowedPublishers(value: LambdaCodeSigningConfigAllowedPublishers[]);
    /**
     * @stability stable
     */
    get allowedPublishersInput(): LambdaCodeSigningConfigAllowedPublishers[];
    private _policies?;
    /**
     * @stability stable
     */
    get policies(): LambdaCodeSigningConfigPolicies[];
    /**
     * @stability stable
     */
    set policies(value: LambdaCodeSigningConfigPolicies[]);
    /**
     * @stability stable
     */
    resetPolicies(): void;
    /**
     * @stability stable
     */
    get policiesInput(): LambdaCodeSigningConfigPolicies[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
