import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface S3BucketInventoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#bucket S3BucketInventory#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#enabled S3BucketInventory#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#included_object_versions S3BucketInventory#included_object_versions}.
     *
     * @stability stable
     */
    readonly includedObjectVersions: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#name S3BucketInventory#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#optional_fields S3BucketInventory#optional_fields}.
     *
     * @stability stable
     */
    readonly optionalFields?: string[];
    /**
     * destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#destination S3BucketInventory#destination}
     *
     * @stability stable
     */
    readonly destination: S3BucketInventoryDestination[];
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#filter S3BucketInventory#filter}
     *
     * @stability stable
     */
    readonly filter?: S3BucketInventoryFilter[];
    /**
     * schedule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#schedule S3BucketInventory#schedule}
     *
     * @stability stable
     */
    readonly schedule: S3BucketInventorySchedule[];
}
/**
 * @stability stable
 */
export interface S3BucketInventoryDestinationBucketEncryptionSseKms {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#key_id S3BucketInventory#key_id}.
     *
     * @stability stable
     */
    readonly keyId: string;
}
/**
 * @stability stable
 */
export interface S3BucketInventoryDestinationBucketEncryptionSseS3 {
}
/**
 * @stability stable
 */
export interface S3BucketInventoryDestinationBucketEncryption {
    /**
     * sse_kms block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#sse_kms S3BucketInventory#sse_kms}
     *
     * @stability stable
     */
    readonly sseKms?: S3BucketInventoryDestinationBucketEncryptionSseKms[];
    /**
     * sse_s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#sse_s3 S3BucketInventory#sse_s3}
     *
     * @stability stable
     */
    readonly sseS3?: S3BucketInventoryDestinationBucketEncryptionSseS3[];
}
/**
 * @stability stable
 */
export interface S3BucketInventoryDestinationBucket {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#account_id S3BucketInventory#account_id}.
     *
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#bucket_arn S3BucketInventory#bucket_arn}.
     *
     * @stability stable
     */
    readonly bucketArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#format S3BucketInventory#format}.
     *
     * @stability stable
     */
    readonly format: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#prefix S3BucketInventory#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * encryption block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#encryption S3BucketInventory#encryption}
     *
     * @stability stable
     */
    readonly encryption?: S3BucketInventoryDestinationBucketEncryption[];
}
/**
 * @stability stable
 */
export interface S3BucketInventoryDestination {
    /**
     * bucket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#bucket S3BucketInventory#bucket}
     *
     * @stability stable
     */
    readonly bucket: S3BucketInventoryDestinationBucket[];
}
/**
 * @stability stable
 */
export interface S3BucketInventoryFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#prefix S3BucketInventory#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
/**
 * @stability stable
 */
export interface S3BucketInventorySchedule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#frequency S3BucketInventory#frequency}.
     *
     * @stability stable
     */
    readonly frequency: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html aws_s3_bucket_inventory}.
 *
 * @stability stable
 */
export declare class S3BucketInventory extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html aws_s3_bucket_inventory} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: S3BucketInventoryConfig);
    private _bucket;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _includedObjectVersions;
    /**
     * @stability stable
     */
    get includedObjectVersions(): string;
    /**
     * @stability stable
     */
    set includedObjectVersions(value: string);
    /**
     * @stability stable
     */
    get includedObjectVersionsInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _optionalFields?;
    /**
     * @stability stable
     */
    get optionalFields(): string[];
    /**
     * @stability stable
     */
    set optionalFields(value: string[]);
    /**
     * @stability stable
     */
    resetOptionalFields(): void;
    /**
     * @stability stable
     */
    get optionalFieldsInput(): string[] | undefined;
    private _destination;
    /**
     * @stability stable
     */
    get destination(): S3BucketInventoryDestination[];
    /**
     * @stability stable
     */
    set destination(value: S3BucketInventoryDestination[]);
    /**
     * @stability stable
     */
    get destinationInput(): S3BucketInventoryDestination[];
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): S3BucketInventoryFilter[];
    /**
     * @stability stable
     */
    set filter(value: S3BucketInventoryFilter[]);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): S3BucketInventoryFilter[] | undefined;
    private _schedule;
    /**
     * @stability stable
     */
    get schedule(): S3BucketInventorySchedule[];
    /**
     * @stability stable
     */
    set schedule(value: S3BucketInventorySchedule[]);
    /**
     * @stability stable
     */
    get scheduleInput(): S3BucketInventorySchedule[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
