import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SagemakerWorkforceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#workforce_name SagemakerWorkforce#workforce_name}.
     *
     * @stability stable
     */
    readonly workforceName: string;
    /**
     * cognito_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#cognito_config SagemakerWorkforce#cognito_config}
     *
     * @stability stable
     */
    readonly cognitoConfig?: SagemakerWorkforceCognitoConfig[];
    /**
     * oidc_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#oidc_config SagemakerWorkforce#oidc_config}
     *
     * @stability stable
     */
    readonly oidcConfig?: SagemakerWorkforceOidcConfig[];
    /**
     * source_ip_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#source_ip_config SagemakerWorkforce#source_ip_config}
     *
     * @stability stable
     */
    readonly sourceIpConfig?: SagemakerWorkforceSourceIpConfig[];
}
/**
 * @stability stable
 */
export interface SagemakerWorkforceCognitoConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#client_id SagemakerWorkforce#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#user_pool SagemakerWorkforce#user_pool}.
     *
     * @stability stable
     */
    readonly userPool: string;
}
/**
 * @stability stable
 */
export interface SagemakerWorkforceOidcConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#authorization_endpoint SagemakerWorkforce#authorization_endpoint}.
     *
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#client_id SagemakerWorkforce#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#client_secret SagemakerWorkforce#client_secret}.
     *
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#issuer SagemakerWorkforce#issuer}.
     *
     * @stability stable
     */
    readonly issuer: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#jwks_uri SagemakerWorkforce#jwks_uri}.
     *
     * @stability stable
     */
    readonly jwksUri: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#logout_endpoint SagemakerWorkforce#logout_endpoint}.
     *
     * @stability stable
     */
    readonly logoutEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#token_endpoint SagemakerWorkforce#token_endpoint}.
     *
     * @stability stable
     */
    readonly tokenEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#user_info_endpoint SagemakerWorkforce#user_info_endpoint}.
     *
     * @stability stable
     */
    readonly userInfoEndpoint: string;
}
/**
 * @stability stable
 */
export interface SagemakerWorkforceSourceIpConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#cidrs SagemakerWorkforce#cidrs}.
     *
     * @stability stable
     */
    readonly cidrs: string[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html aws_sagemaker_workforce}.
 *
 * @stability stable
 */
export declare class SagemakerWorkforce extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html aws_sagemaker_workforce} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SagemakerWorkforceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get subdomain(): string;
    private _workforceName;
    /**
     * @stability stable
     */
    get workforceName(): string;
    /**
     * @stability stable
     */
    set workforceName(value: string);
    /**
     * @stability stable
     */
    get workforceNameInput(): string;
    private _cognitoConfig?;
    /**
     * @stability stable
     */
    get cognitoConfig(): SagemakerWorkforceCognitoConfig[];
    /**
     * @stability stable
     */
    set cognitoConfig(value: SagemakerWorkforceCognitoConfig[]);
    /**
     * @stability stable
     */
    resetCognitoConfig(): void;
    /**
     * @stability stable
     */
    get cognitoConfigInput(): SagemakerWorkforceCognitoConfig[] | undefined;
    private _oidcConfig?;
    /**
     * @stability stable
     */
    get oidcConfig(): SagemakerWorkforceOidcConfig[];
    /**
     * @stability stable
     */
    set oidcConfig(value: SagemakerWorkforceOidcConfig[]);
    /**
     * @stability stable
     */
    resetOidcConfig(): void;
    /**
     * @stability stable
     */
    get oidcConfigInput(): SagemakerWorkforceOidcConfig[] | undefined;
    private _sourceIpConfig?;
    /**
     * @stability stable
     */
    get sourceIpConfig(): SagemakerWorkforceSourceIpConfig[];
    /**
     * @stability stable
     */
    set sourceIpConfig(value: SagemakerWorkforceSourceIpConfig[]);
    /**
     * @stability stable
     */
    resetSourceIpConfig(): void;
    /**
     * @stability stable
     */
    get sourceIpConfigInput(): SagemakerWorkforceSourceIpConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
