import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TransferAccessConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#external_id TransferAccess#external_id}.
     *
     * @stability stable
     */
    readonly externalId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#home_directory TransferAccess#home_directory}.
     *
     * @stability stable
     */
    readonly homeDirectory?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#home_directory_type TransferAccess#home_directory_type}.
     *
     * @stability stable
     */
    readonly homeDirectoryType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#policy TransferAccess#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#role TransferAccess#role}.
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#server_id TransferAccess#server_id}.
     *
     * @stability stable
     */
    readonly serverId: string;
    /**
     * home_directory_mappings block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#home_directory_mappings TransferAccess#home_directory_mappings}
     *
     * @stability stable
     */
    readonly homeDirectoryMappings?: TransferAccessHomeDirectoryMappings[];
    /**
     * posix_profile block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#posix_profile TransferAccess#posix_profile}
     *
     * @stability stable
     */
    readonly posixProfile?: TransferAccessPosixProfile[];
}
/**
 * @stability stable
 */
export interface TransferAccessHomeDirectoryMappings {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#entry TransferAccess#entry}.
     *
     * @stability stable
     */
    readonly entry: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#target TransferAccess#target}.
     *
     * @stability stable
     */
    readonly target: string;
}
/**
 * @stability stable
 */
export interface TransferAccessPosixProfile {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#gid TransferAccess#gid}.
     *
     * @stability stable
     */
    readonly gid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#secondary_gids TransferAccess#secondary_gids}.
     *
     * @stability stable
     */
    readonly secondaryGids?: number[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#uid TransferAccess#uid}.
     *
     * @stability stable
     */
    readonly uid: number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html aws_transfer_access}.
 *
 * @stability stable
 */
export declare class TransferAccess extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html aws_transfer_access} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: TransferAccessConfig);
    private _externalId;
    /**
     * @stability stable
     */
    get externalId(): string;
    /**
     * @stability stable
     */
    set externalId(value: string);
    /**
     * @stability stable
     */
    get externalIdInput(): string;
    private _homeDirectory?;
    /**
     * @stability stable
     */
    get homeDirectory(): string;
    /**
     * @stability stable
     */
    set homeDirectory(value: string);
    /**
     * @stability stable
     */
    resetHomeDirectory(): void;
    /**
     * @stability stable
     */
    get homeDirectoryInput(): string | undefined;
    private _homeDirectoryType?;
    /**
     * @stability stable
     */
    get homeDirectoryType(): string;
    /**
     * @stability stable
     */
    set homeDirectoryType(value: string);
    /**
     * @stability stable
     */
    resetHomeDirectoryType(): void;
    /**
     * @stability stable
     */
    get homeDirectoryTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _serverId;
    /**
     * @stability stable
     */
    get serverId(): string;
    /**
     * @stability stable
     */
    set serverId(value: string);
    /**
     * @stability stable
     */
    get serverIdInput(): string;
    private _homeDirectoryMappings?;
    /**
     * @stability stable
     */
    get homeDirectoryMappings(): TransferAccessHomeDirectoryMappings[];
    /**
     * @stability stable
     */
    set homeDirectoryMappings(value: TransferAccessHomeDirectoryMappings[]);
    /**
     * @stability stable
     */
    resetHomeDirectoryMappings(): void;
    /**
     * @stability stable
     */
    get homeDirectoryMappingsInput(): TransferAccessHomeDirectoryMappings[] | undefined;
    private _posixProfile?;
    /**
     * @stability stable
     */
    get posixProfile(): TransferAccessPosixProfile[];
    /**
     * @stability stable
     */
    set posixProfile(value: TransferAccessPosixProfile[]);
    /**
     * @stability stable
     */
    resetPosixProfile(): void;
    /**
     * @stability stable
     */
    get posixProfileInput(): TransferAccessPosixProfile[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
