import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface VpcEndpointServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#acceptance_required VpcEndpointService#acceptance_required}.
     *
     * @stability stable
     */
    readonly acceptanceRequired: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#allowed_principals VpcEndpointService#allowed_principals}.
     *
     * @stability stable
     */
    readonly allowedPrincipals?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#gateway_load_balancer_arns VpcEndpointService#gateway_load_balancer_arns}.
     *
     * @stability stable
     */
    readonly gatewayLoadBalancerArns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#network_load_balancer_arns VpcEndpointService#network_load_balancer_arns}.
     *
     * @stability stable
     */
    readonly networkLoadBalancerArns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#private_dns_name VpcEndpointService#private_dns_name}.
     *
     * @stability stable
     */
    readonly privateDnsName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#tags VpcEndpointService#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#tags_all VpcEndpointService#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class VpcEndpointServicePrivateDnsNameConfiguration extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get state(): string;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    get value(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html aws_vpc_endpoint_service}.
 *
 * @stability stable
 */
export declare class VpcEndpointService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html aws_vpc_endpoint_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: VpcEndpointServiceConfig);
    private _acceptanceRequired;
    /**
     * @stability stable
     */
    get acceptanceRequired(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set acceptanceRequired(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get acceptanceRequiredInput(): boolean | cdktf.IResolvable;
    private _allowedPrincipals?;
    /**
     * @stability stable
     */
    get allowedPrincipals(): string[];
    /**
     * @stability stable
     */
    set allowedPrincipals(value: string[]);
    /**
     * @stability stable
     */
    resetAllowedPrincipals(): void;
    /**
     * @stability stable
     */
    get allowedPrincipalsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get availabilityZones(): string[];
    /**
     * @stability stable
     */
    get baseEndpointDnsNames(): string[];
    private _gatewayLoadBalancerArns?;
    /**
     * @stability stable
     */
    get gatewayLoadBalancerArns(): string[];
    /**
     * @stability stable
     */
    set gatewayLoadBalancerArns(value: string[]);
    /**
     * @stability stable
     */
    resetGatewayLoadBalancerArns(): void;
    /**
     * @stability stable
     */
    get gatewayLoadBalancerArnsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get managesVpcEndpoints(): cdktf.IResolvable;
    private _networkLoadBalancerArns?;
    /**
     * @stability stable
     */
    get networkLoadBalancerArns(): string[];
    /**
     * @stability stable
     */
    set networkLoadBalancerArns(value: string[]);
    /**
     * @stability stable
     */
    resetNetworkLoadBalancerArns(): void;
    /**
     * @stability stable
     */
    get networkLoadBalancerArnsInput(): string[] | undefined;
    private _privateDnsName?;
    /**
     * @stability stable
     */
    get privateDnsName(): string;
    /**
     * @stability stable
     */
    set privateDnsName(value: string);
    /**
     * @stability stable
     */
    resetPrivateDnsName(): void;
    /**
     * @stability stable
     */
    get privateDnsNameInput(): string | undefined;
    /**
     * @stability stable
     */
    privateDnsNameConfiguration(index: string): VpcEndpointServicePrivateDnsNameConfiguration;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    get serviceType(): string;
    /**
     * @stability stable
     */
    get state(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
