import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface WorkspacesDirectoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#directory_id WorkspacesDirectory#directory_id}.
     *
     * @stability stable
     */
    readonly directoryId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#ip_group_ids WorkspacesDirectory#ip_group_ids}.
     *
     * @stability stable
     */
    readonly ipGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#subnet_ids WorkspacesDirectory#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#tags WorkspacesDirectory#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#tags_all WorkspacesDirectory#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * self_service_permissions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#self_service_permissions WorkspacesDirectory#self_service_permissions}
     *
     * @stability stable
     */
    readonly selfServicePermissions?: WorkspacesDirectorySelfServicePermissions[];
    /**
     * workspace_access_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#workspace_access_properties WorkspacesDirectory#workspace_access_properties}
     *
     * @stability stable
     */
    readonly workspaceAccessProperties?: WorkspacesDirectoryWorkspaceAccessProperties[];
    /**
     * workspace_creation_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#workspace_creation_properties WorkspacesDirectory#workspace_creation_properties}
     *
     * @stability stable
     */
    readonly workspaceCreationProperties?: WorkspacesDirectoryWorkspaceCreationProperties[];
}
/**
 * @stability stable
 */
export interface WorkspacesDirectorySelfServicePermissions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#change_compute_type WorkspacesDirectory#change_compute_type}.
     *
     * @stability stable
     */
    readonly changeComputeType?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#increase_volume_size WorkspacesDirectory#increase_volume_size}.
     *
     * @stability stable
     */
    readonly increaseVolumeSize?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#rebuild_workspace WorkspacesDirectory#rebuild_workspace}.
     *
     * @stability stable
     */
    readonly rebuildWorkspace?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#restart_workspace WorkspacesDirectory#restart_workspace}.
     *
     * @stability stable
     */
    readonly restartWorkspace?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#switch_running_mode WorkspacesDirectory#switch_running_mode}.
     *
     * @stability stable
     */
    readonly switchRunningMode?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectoryWorkspaceAccessProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_android WorkspacesDirectory#device_type_android}.
     *
     * @stability stable
     */
    readonly deviceTypeAndroid?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_chromeos WorkspacesDirectory#device_type_chromeos}.
     *
     * @stability stable
     */
    readonly deviceTypeChromeos?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_ios WorkspacesDirectory#device_type_ios}.
     *
     * @stability stable
     */
    readonly deviceTypeIos?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_linux WorkspacesDirectory#device_type_linux}.
     *
     * @stability stable
     */
    readonly deviceTypeLinux?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_osx WorkspacesDirectory#device_type_osx}.
     *
     * @stability stable
     */
    readonly deviceTypeOsx?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_web WorkspacesDirectory#device_type_web}.
     *
     * @stability stable
     */
    readonly deviceTypeWeb?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_windows WorkspacesDirectory#device_type_windows}.
     *
     * @stability stable
     */
    readonly deviceTypeWindows?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_zeroclient WorkspacesDirectory#device_type_zeroclient}.
     *
     * @stability stable
     */
    readonly deviceTypeZeroclient?: string;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectoryWorkspaceCreationProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#custom_security_group_id WorkspacesDirectory#custom_security_group_id}.
     *
     * @stability stable
     */
    readonly customSecurityGroupId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#default_ou WorkspacesDirectory#default_ou}.
     *
     * @stability stable
     */
    readonly defaultOu?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#enable_internet_access WorkspacesDirectory#enable_internet_access}.
     *
     * @stability stable
     */
    readonly enableInternetAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#enable_maintenance_mode WorkspacesDirectory#enable_maintenance_mode}.
     *
     * @stability stable
     */
    readonly enableMaintenanceMode?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#user_enabled_as_local_administrator WorkspacesDirectory#user_enabled_as_local_administrator}.
     *
     * @stability stable
     */
    readonly userEnabledAsLocalAdministrator?: boolean | cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html aws_workspaces_directory}.
 *
 * @stability stable
 */
export declare class WorkspacesDirectory extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html aws_workspaces_directory} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkspacesDirectoryConfig);
    /**
     * @stability stable
     */
    get alias(): string;
    /**
     * @stability stable
     */
    get customerUserName(): string;
    private _directoryId;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    get directoryIdInput(): string;
    /**
     * @stability stable
     */
    get directoryName(): string;
    /**
     * @stability stable
     */
    get directoryType(): string;
    /**
     * @stability stable
     */
    get dnsIpAddresses(): string[];
    /**
     * @stability stable
     */
    get iamRoleId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipGroupIds?;
    /**
     * @stability stable
     */
    get ipGroupIds(): string[];
    /**
     * @stability stable
     */
    set ipGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetIpGroupIds(): void;
    /**
     * @stability stable
     */
    get ipGroupIdsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get registrationCode(): string;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get workspaceSecurityGroupId(): string;
    private _selfServicePermissions?;
    /**
     * @stability stable
     */
    get selfServicePermissions(): WorkspacesDirectorySelfServicePermissions[];
    /**
     * @stability stable
     */
    set selfServicePermissions(value: WorkspacesDirectorySelfServicePermissions[]);
    /**
     * @stability stable
     */
    resetSelfServicePermissions(): void;
    /**
     * @stability stable
     */
    get selfServicePermissionsInput(): WorkspacesDirectorySelfServicePermissions[] | undefined;
    private _workspaceAccessProperties?;
    /**
     * @stability stable
     */
    get workspaceAccessProperties(): WorkspacesDirectoryWorkspaceAccessProperties[];
    /**
     * @stability stable
     */
    set workspaceAccessProperties(value: WorkspacesDirectoryWorkspaceAccessProperties[]);
    /**
     * @stability stable
     */
    resetWorkspaceAccessProperties(): void;
    /**
     * @stability stable
     */
    get workspaceAccessPropertiesInput(): WorkspacesDirectoryWorkspaceAccessProperties[] | undefined;
    private _workspaceCreationProperties?;
    /**
     * @stability stable
     */
    get workspaceCreationProperties(): WorkspacesDirectoryWorkspaceCreationProperties[];
    /**
     * @stability stable
     */
    set workspaceCreationProperties(value: WorkspacesDirectoryWorkspaceCreationProperties[]);
    /**
     * @stability stable
     */
    resetWorkspaceCreationProperties(): void;
    /**
     * @stability stable
     */
    get workspaceCreationPropertiesInput(): WorkspacesDirectoryWorkspaceCreationProperties[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
